==> oce_0.12.orig.tar.gz: oce-OCE-0.12/src/RWStepBasic/RWStepBasic_RWNameAssignment.cxx <==
// Created on: 2000-05-10
// Created by: Andrey BETENEV
// Copyright (c) 2000-2012 OPEN CASCADE SAS
//
// The content of this file is subject to the Open CASCADE Technology Public
// License Version 6.5 (the "License"). You may not use the content of this file
// except in compliance with the License. Please obtain a copy of the License
// at http://www.opencascade.org and read it completely before using this file.
//
// The Initial Developer of the Original Code is Open CASCADE S.A.S., having its
// main offices at: 1, place des Freres Montgolfier, 78280 Guyancourt, France.
//
// The Original Code and all software distributed under the License is
// distributed on an "AS IS" basis, without warranty of any kind, and the
// Initial Developer hereby disclaims all such warranties, including without
// limitation, any warranties of merchantability, fitness for a particular
// purpose or non-infringement. Please see the License for the specific terms
// and conditions governing the rights and limitations under the License.

// Generator:	ExpToCas (EXPRESS -> CASCADE/XSTEP Translator) V1.1

#include <RWStepBasic_RWNameAssignment.ixx>

//=======================================================================
//function : RWStepBasic_RWNameAssignment
//purpose  : 
//=======================================================================

RWStepBasic_RWNameAssignment::RWStepBasic_RWNameAssignment ()
{
}

//=======================================================================
//function : ReadStep
//purpose  : 
//=======================================================================

void RWStepBasic_RWNameAssignment::ReadStep (const Handle(StepData_StepReaderData)& data,
                                             const Standard_Integer num,
                                             Handle(Interface_Check)& ach,
                                             const Handle(StepBasic_NameAssignment) &ent) const
{
  // Check number of parameters
  if ( ! data->CheckNbParams(num,1,ach,"name_assignment") ) return;

  // Own fields of NameAssignment

  Handle(TCollection_HAsciiString) aAssignedName;
  data->ReadString (num, 1, "assigned_name", ach, aAssignedName);

  // Initialize entity
  ent->Init(aAssignedName);
}

//=======================================================================
//function : WriteStep
//purpose  : 
//=======================================================================

void RWStepBasic_RWNameAssignment::WriteStep (StepData_StepWriter& SW,
                                              const Handle(StepBasic_NameAssignment) &ent) const
{

  // Own fields of NameAssignment

  SW.Send (ent->AssignedName());
}

//=======================================================================
//function : Share
//purpose  : 
//=======================================================================

void RWStepBasic_RWNameAssignment::Share (const Handle(StepBasic_NameAssignment) &ent,
                                          Interface_EntityIterator& iter) const
{

  // Own fields of NameAssignment
}

==> oce_0.15.orig.tar.gz: oce-OCE-0.15/src/RWStepBasic/RWStepBasic_RWNameAssignment.cxx <==
// Created on: 2000-05-10
// Created by: Andrey BETENEV
// Copyright (c) 2000-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and / or modify it
// under the terms of the GNU Lesser General Public version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

// Generator:	ExpToCas (EXPRESS -> CASCADE/XSTEP Translator) V1.1

#include <RWStepBasic_RWNameAssignment.ixx>

//=======================================================================
//function : RWStepBasic_RWNameAssignment
//purpose  : 
//=======================================================================

RWStepBasic_RWNameAssignment::RWStepBasic_RWNameAssignment ()
{
}

//=======================================================================
//function : ReadStep
//purpose  : 
//=======================================================================

void RWStepBasic_RWNameAssignment::ReadStep (const Handle(StepData_StepReaderData)& data,
                                             const Standard_Integer num,
                                             Handle(Interface_Check)& ach,
                                             const Handle(StepBasic_NameAssignment) &ent) const
{
  // Check number of parameters
  if ( ! data->CheckNbParams(num,1,ach,"name_assignment") ) return;

  // Own fields of NameAssignment

  Handle(TCollection_HAsciiString) aAssignedName;
  data->ReadString (num, 1, "assigned_name", ach, aAssignedName);

  // Initialize entity
  ent->Init(aAssignedName);
}

//=======================================================================
//function : WriteStep
//purpose  : 
//=======================================================================

void RWStepBasic_RWNameAssignment::WriteStep (StepData_StepWriter& SW,
                                              const Handle(StepBasic_NameAssignment) &ent) const
{

  // Own fields of NameAssignment

  SW.Send (ent->AssignedName());
}

//=======================================================================
//function : Share
//purpose  : 
//=======================================================================

void RWStepBasic_RWNameAssignment::Share (const Handle(StepBasic_NameAssignment) &,
                                          Interface_EntityIterator&) const
{
  // Own fields of NameAssignment
}
